( cd usr/lib64 ; rm -rf libsoup-3.0.so )
( cd usr/lib64 ; ln -sf libsoup-3.0.so.0 libsoup-3.0.so )
( cd usr/lib64 ; rm -rf libsoup-3.0.so.0 )
( cd usr/lib64 ; ln -sf libsoup-3.0.so.0.6.0 libsoup-3.0.so.0 )
